<?php

namespace Drupal\dpxu\Plugin\views\area;

use Drupal\views\Plugin\views\area\AreaPluginBase;
use Drupal\Core\Access\AccessManagerInterface;
use Drupal\Core\Url;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines an area plugin to display a create user link.
 *
 * @ingroup views_area_handlers
 *
 * @ViewsArea("dpxu_create_user_link")
 */
class ProxyUserAddNewUser extends AreaPluginBase {

  /**
   * The access manager.
   *
   * @var \Drupal\Core\Access\AccessManagerInterface
   */
  protected $accessManager;

  /**
   * The current user service.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Constructs a new ProxyUserAddNewUser object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Access\AccessManagerInterface $access_manager
   *   The access manager.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   The current user service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, AccessManagerInterface $access_manager, AccountProxyInterface $current_user) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->accessManager = $access_manager;
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($configuration, $plugin_id, $plugin_definition, $container->get('access_manager'), $container->get('current_user'));
  }

  /**
   * {@inheritdoc}
   */
  public function render($empty = FALSE) {
    if (!$empty || !empty($this->options['empty'])) {
      $element = [
        '#theme' => 'links',
        '#links' => [
          [
            'url' => Url::fromRoute('dpxu.user_create', [],
              [
                'absolute' => TRUE,
                'attributes' => [
                  'class' => ['btn', 'btn-primary'],
                  'role' => 'button',
                  'aria-label' => $this->t('Add new managed user'),
                ],
              ]),
            'title' => $this->t('Add new managed user'),
          ],
        ],
        '#access' => $this->accessManager
          ->checkNamedRoute('dpxu.user_create', [], $this->currentUser),
      ];
      return $element;
    }
    return [];
  }

}
