<?php

namespace Drupal\dpxu\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;
use Drupal\dpxu\ProxyUserTools;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Field handler for reason why the user contacted manager.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("dpxu_user_message_reason")
 */
class ProxyUserMessageReason extends FieldPluginBase {

  /**
   * Proxy User Tools service.
   *
   * @var \Drupal\dpxu\ProxyUserTools
   */
  private $userTools;

  /**
   * Constructs the ProxyUserMessageReason object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\dpxu\ProxyUserTools $user_tools
   *   The user tools service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ProxyUserTools $user_tools) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->userTools = $user_tools;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($configuration, $plugin_id, $plugin_definition, $container->get('dpxu.user_tools'));
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $user = $values->_entity;
    $value = $this->userTools->readContactReasonFromTempStore($user->id());
    return $this->sanitizeValue($value);
  }

}
